2004-11-26 Andrew J. Schorr <ajschorr@alumni.princeton.edu>

	* log.c, log.h, memory.c: Change function name from zlog_backtrace_safe
	  to the more self-explanatory zlog_backtrace_sigsafe.
diff --git a/lib/memory.c b/lib/memory.c
index 0d23e54..8e2c4fa 100644
--- a/lib/memory.c
+++ b/lib/memory.c
@@ -46,9 +46,9 @@
   zlog_err ("%s : can't allocate memory for `%s' size %d: %s\n", 
 	    fname, lookup (mstr, type), (int) size, safe_strerror(errno));
   log_memstats(LOG_WARNING);
   /* N.B. It might be preferable to call zlog_backtrace_safe here, since
      that function should definitely be safe in an OOM condition.  But
-     unfortunately zlog_backtrace_safe does not support syslog logging at
+     unfortunately zlog_backtrace_sigsafe does not support syslog logging at
      this time... */
   zlog_backtrace(LOG_WARNING);
   abort();
@@ -46,9 +46,9 @@
 	    fname, lookup (mstr, type), (int) size, safe_strerror(errno));
   log_memstats(LOG_WARNING);
-  /* N.B. It might be preferable to call zlog_backtrace_safe here, since
+  /* N.B. It might be preferable to call zlog_backtrace_sigsafe here, since
      that function should definitely be safe in an OOM condition.  But